# <img src='https://raw.githack.com/FortAwesome/Font-Awesome/master/svgs/solid/volume-down.svg' card_color='#22a7f0' width='50' height='50' style='vertical-align:bottom'/> Volume Control
Control the volume of your system

## About
Control the volume of Mycroft with verbal commands 

## Examples
* "Turn up the volume"
* "Decrease the audio"
* "Mute audio"
* "Set volume to 5"
* "Set volume to 75 percent"

## Credits
Mycroft AI (@MycroftAI)

## Category
**Configuration**

## Tags
#volume
#volume-control
#sound
#system
